@@ -187,6 +187,43 @@ ppd_hist <-
       facet_text(FALSE)
   }
 
+#' @rdname PPD-distributions
+#' @export
+ppd_dots <-
+  function(ypred,
+           ...,
+           binwidth = NA,
+           quantiles = NA,
+           freq = TRUE) {
+    check_ignored_arguments(..., ok_args = c("dotsize", "layout", "stackratio", "overflow"))
+
+    suggested_package("ggdist")
+
+    data <- ppd_data(ypred)
+    ggplot(data, mapping = set_hist_aes(
+      freq,
+      color = "ypred",
+      fill = "ypred"
+    )) +
+      ggdist::stat_dots(
+        binwidth = binwidth,
+        quantiles = quantiles,
+        ...
+      ) +
+      scale_color_ppd() +
+      scale_fill_ppd() +
+      bayesplot_theme_get() +
+      facet_wrap_parsed("rep_label") +
+      force_axes_in_facets() +
+      dont_expand_y_axis() +
+      legend_none() +
+      yaxis_text(FALSE) +
+      yaxis_title(FALSE) +
+      yaxis_ticks(FALSE) +
+      xaxis_title(FALSE) +
+      facet_text(FALSE)
+  }
+
 
 #' @rdname PPD-distributions
 #' @export
